==> haskell-fgl-arbitrary-0.2.0.6-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-DGE5ghpWD20Dn9YTRec1FD
key:                  fgl-arbitrary-0.2.0.6-DGE5ghpWD20Dn9YTRec1FD
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  f5957aa2ccd78e4bcf1575d6d22a5925
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-8.10.4/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/fgl-arbitrary-0.2.0.6
hs-libraries:         HSfgl-arbitrary-0.2.0.6-DGE5ghpWD20Dn9YTRec1FD
depends:
    QuickCheck-2.14.2-JBdTpAobWwg19WOWKtgrIg base-4.14.1.0
    fgl-5.7.0.3-LTyD6msTIrSCd0tz18dS5q

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-arbitrary-0.2.0.6-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-5R6nArpxKN0BNJSKS02kNv
key:                  fgl-arbitrary-0.2.0.6-5R6nArpxKN0BNJSKS02kNv
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  6e595bbf32ba660b40a7ef79c9b9ba4b
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-8.10.4/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-8.10.4/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/fgl-arbitrary-0.2.0.6
hs-libraries:         HSfgl-arbitrary-0.2.0.6-5R6nArpxKN0BNJSKS02kNv
depends:
    QuickCheck-2.14.2-3W2gU4yWpUZKQgtIeJuCof base-4.14.1.0
    fgl-5.7.0.3-ERVAJoVdEuj2eW7a4FoOMX

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
